<img src="Voicelab/favicon.ico">**VoiceLab**
======
**Automated Reproducible Acoustical Analysis**



## Contributors
David Feinberg, PhD  

Oliver Cook

## Version 
* Version 0.1

## Contact
- feinberg@mcmaster.ca

## Citing Voicelab
Feinberg, D. R., & Cook, O. (2020, September 15). VoiceLab: Automated Reproducible Acoustic Analysis. Retrieved from psyarxiv.com/v5uxf

## Documentation
- https://voice-lab.github.io/VoiceLab/

## Precompiled binaries
- Windows exe file and Linux binary, and OSX app file are here: https://github.com/Voice-Lab/VoiceLab/releases
- OSX binary is in a zip file, don't forget to unzip it


## Python package installation instructions
pip install Voicelab

## To run Voicelab
python voicelab.py
